require 'openssl'
require 'vcr'

class VcrEncryptor

  def encrypt(string)
    cipher = init_cipher(:encrypt)
    cipher.update(string) + cipher.final
  end

  def decrypt(string)
    decipher = init_cipher(:decrypt)
    decipher.update(string) + decipher.final
  end

  private

  def init_cipher(type)
    OpenSSL::Cipher::AES256.new(:CBC).tap do |cipher|
      type == :encrypt ? cipher.encrypt : cipher.decrypt
      cipher.key = ENV['RAILS_MASTER_KEY']
    end
  end

end

encrypted_serializer = Object.new
class << encrypted_serializer
  def file_extension; "enc"; end
  def serialize(hash); VcrEncryptor.new.encrypt(hash.to_json); end
  def deserialize(string); JSON.parse(VcrEncryptor.new.decrypt(string)); end
end


VCR.configure do |c|
  c.cassette_library_dir = "spec/cassettes"
  c.cassette_serializers[:enc] = encrypted_serializer
  c.default_cassette_options = { :serialize_with => :enc }
  c.hook_into :webmock
  c.configure_rspec_metadata!
  c.ignore_localhost = true
end

