require 'spec_helper'
require 'pry'

RSpec.describe 'api' do
  before do
    @client = Ucb::Hcm::Client.new(app_id: TestCredentials::TEST_APP_ID, app_key: TestCredentials::TEST_APP_KEY)
  end

  describe "#get" do
    describe "GET /employees/:id", :vcr do
      it "returns employee data w/ valid id & legacy-hr-employee-type" do
        response = @client.get("/employees/10161331", {"id-type" => "hr-employee-id"})

        expect(response.success?).to eq true
        data = response.all.first
        expect(data["identifiers"].first.has_key?("type")).to eq true

        names = data["names"]
        expect(names.empty? || names.first.has_key?("familyName")).to eq true

        addresses = data["addresses"]
        expect(addresses.empty? || addresses.first.has_key?("address1")).to eq true

        emails = data["emails"]
        expect(emails.empty? || emails.first.has_key?("emailAddress")).to eq true

        phones = data["phones"]
        expect(phones.empty? || phones.first.has_key?("number")).to eq true
      end

      # this should return 404
      it "succeeds with invalid id-type" do
        response = @client.get("/employees/10135532", {"id-type" => "invalid-type"})

        expect(response.success?).to be false
      end

      # this should return 400
      it "returns empty response if id is invalid" do
        response = @client.get("/employees/invalidId", {"id-type" => "legacy-hr-employee-id"})

        expect(response.success?).to be false
        expect(response.all.first).to be_nil
      end
    end

    describe "fetch employee jobs", :vcr do
      it "returns all an employees jobs" do
        response = @client.get("/employees/10161331/jobs", {"id-type" => "hr-employee-id"})

        expect(response.success?).to eq true

        job = response.all.first["jobs"].first
        expect(job.has_key?("compensation")).to eq true
      end
    end

    describe "GET /employees", :vcr do
      it "supports pagination" do
        params = {
          limit: 5,
          previous: 0,
          next: 5
        }

        response = @client.get("/employees", params)

        expect(response.all.count).to eq 5
      end
    end
  end
end
