require "spec_helper"
require "pry"

RSpec.describe "response" do
  let(:fetcher) { Ucb::Hcm::DataFetcher.new(TEST_RESPONSE["response"].first) } # TEST_RESPONSE defined in spec_helper

  it "can respond to dot notation" do
    expect(fetcher.gender.genderOfRecord.code.value).to eq("M")
  end

  it "returns nil if any part of the call chain cannot be found in the response" do
    expect(fetcher.notInTheResponse.genderOfRecord.code.value).to eq(nil)
  end

  it "returns the specified default value if any part of the call chain cannot be found in the response" do
    expect(fetcher.notInTheResponse.genderOfRecord.code.value("not found")).to eq("not found")
  end

  it "can respond to snake case as well as camel case" do
    expect(fetcher.gender.gender_of_record.from_date.value).to eq("2015-08-01")
  end

  it "can handle arrays in the call chain" do
    expect(fetcher.names.first.type.code.value).to eq("PRI")
  end

  it "can be reused" do
    fetcher.names.first.type.code.value
    expect(fetcher.names.first.type.code.value).to eq("PRI")
  end

  it "can handle arrays with bracket notation" do
    expect(fetcher.names[0].type.code.value).to eq("PRI")
  end

  it "can respond to accessing the data as a hash" do
    expect(fetcher["names"].first["type"]["code"].value).to eq("PRI")
  end

end

