require "spec_helper"

RSpec.describe "response" do
  let(:raw_response) { TEST_RESPONSE } # TEST_RESPONSE defined in spec_helper
  let(:response) {
    allow(raw_response).to receive(:code) { "200" }
    Ucb::Hcm::Response.new(raw_response)
  }

  it "returns the HTTP status code" do
    expect(response.code).to eq("200")
  end

  it "returns the underlying JSON data" do
    expect(response.all).to eq(TEST_RESPONSE["response"])
  end

  it "can iterate through the responses" do
    count = 0
    response.each do |item|
      expect(item["names"]).to be_a(Array)
      count += 1
    end
    expect(count).to eq(2)
  end

  it "returns an empty list when calling #all if the response was empty" do
    response = Ucb::Hcm::Response.new(nil)
    expect(response.all).to be_empty
  end

  it "returns an empty list when calling #all if the response does not have a 'response' element" do
    response = Ucb::Hcm::Response.new({foo: "bar"})
    expect(response.all).to be_empty
  end

  it "returns a working iterator if the response was empty" do
    response = Ucb::Hcm::Response.new({foo: "bar"})
    count = 0
    response.each do |item|
      count += 1
    end
    expect(count).to eq(0)
  end

  it "returns the underlying JSON data wrapped in DataFetcher instances" do
    response_fetchers = TEST_RESPONSE["response"].map { |item| Ucb::Hcm::DataFetcher.new(item) }
    expect(response.all_fetchers.map(&:class)).to eq(response_fetchers.map(&:class))
  end

  it "can interate through a list of DataFetcher instances" do
    count = 0
    response.each_fetcher do |item|
      expect(item).to be_a(Ucb::Hcm::DataFetcher)
      count += 1
    end
    expect(count).to eq(2)
  end

end

